@@ -1,16 +1,21 @@
-import json
+from werkzeug.exceptions import HTTPException as _HTTPException
 
 
-class HTTPException(Exception):
+EXC = _HTTPException
+
+
+class HTTPException(EXC):
     message: str
     code: int
 
     def __init__(self, msg=None):
+        # super().__init__()
+        super(EXC, self).__init__(str(msg or self.message))
         if msg:
-            self.msg = msg
+            self.message = msg
 
-    def with_traceback(self, tb) -> BaseException:
-        return True
+    # def with_traceback(self, tb) -> BaseException:
+    #     return True
 
     def pack(self):
         return dict(error=self.message, msg=getattr(self, 'msg', '')), self.code
@@ -18,8 +23,11 @@ class HTTPException(Exception):
     def __str__(self):
         return self.message
 
-    def __dict__(self):
-        return self.pack()
+    def __repr__(self):
+        return self.message
+
+    # def __dict__(self):
+    #     return self.pack()
 
 
 class HTTPClientError(HTTPException):
@@ -38,7 +46,7 @@ class HTTPNotProcessable(HTTPException):
 
 class HTTPNotFound(HTTPException):
     code = 404
-    message = 'Resource does not exist 2'
+    message = 'Resource does not exist'
 
 
 class HTTPConflict(HTTPException):
